@@ -18,7 +18,7 @@ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLI
 * Author:  Olivier PLATHEY                                                     *
 *******************************************************************************/
 
-// Modifications by Michael Larabel 2015 for PTS adaptation of FPDF
+// Modifications by Michael Larabel 2015-2016 for PTS adaptation of FPDF
 
 define('FPDF_VERSION','1.7');
 
@@ -945,6 +945,55 @@ function Image($file, $x=null, $y=null, $w=0, $h=0, $type='', $link='')
 	if($link)
 		$this->Link($x,$y,$w,$h,$link);
 }
+function ImageJPGInline($contents, $x=null, $y=null, $w=0, $h=0, $type='', $link='')
+{
+	// Put an image on the page
+	$file = md5($contents);
+	if(!isset($this->images[$file]))
+	{
+		$info = $this->_parsejpginline($contents);
+		$info['i'] = count($this->images)+1;
+		$this->images[$file] = $info;
+	}
+	else
+		$info = $this->images[$file];
+
+	// Automatic width and height calculation if needed
+	if($w==0 && $h==0)
+	{
+		// Put image at 96 dpi
+		$w = -96;
+		$h = -96;
+	}
+	if($w<0)
+		$w = -$info['w']*72/$w/$this->k;
+	if($h<0)
+		$h = -$info['h']*72/$h/$this->k;
+	if($w==0)
+		$w = $h*$info['w']/$info['h'];
+	if($h==0)
+		$h = $w*$info['h']/$info['w'];
+
+	// Flowing mode
+	if($y===null)
+	{
+		if($this->y+$h>$this->PageBreakTrigger && !$this->InHeader && !$this->InFooter && $this->AcceptPageBreak())
+		{
+			// Automatic page break
+			$x2 = $this->x;
+			$this->AddPage($this->CurOrientation,$this->CurPageSize);
+			$this->x = $x2;
+		}
+		$y = $this->y;
+		$this->y += $h;
+	}
+
+	if($x===null)
+		$x = $this->x;
+	$this->_out(sprintf('q %.2F 0 0 %.2F %.2F %.2F cm /I%d Do Q',$w*$this->k,$h*$this->k,$x*$this->k,($this->h-($y+$h))*$this->k,$info['i']));
+	if($link)
+		$this->Link($x,$y,$w,$h,$link);
+}
 
 function GetX()
 {
@@ -1309,6 +1358,23 @@ function _parsejpg($file)
 	$data = file_get_contents($file);
 	return array('w'=>$a[0], 'h'=>$a[1], 'cs'=>$colspace, 'bpc'=>$bpc, 'f'=>'DCTDecode', 'data'=>$data);
 }
+function _parsejpginline($data)
+{
+	// Extract info from a JPEG file
+	$a = getimagesizefromstring($data);
+	if(!$a)
+		$this->Error('Missing or incorrect image file: ');
+	if($a[2]!=2)
+		$this->Error('Not a JPEG file: ');
+	if(!isset($a['channels']) || $a['channels']==3)
+		$colspace = 'DeviceRGB';
+	elseif($a['channels']==4)
+		$colspace = 'DeviceCMYK';
+	else
+	$colspace = 'DeviceGray';
+	$bpc = isset($a['bits']) ? $a['bits'] : 8;
+	return array('w'=>$a[0], 'h'=>$a[1], 'cs'=>$colspace, 'bpc'=>$bpc, 'f'=>'DCTDecode', 'data'=> $data);
+}
 
 function _parsepng($file)
 {
