@@ -51,6 +51,7 @@ class pts_test_run_manager
 	protected $dynamic_run_count_std_deviation_threshold;
 	protected $dynamic_run_count_export_script;
 	protected $multi_test_stress_run = false;
+	protected $allow_test_cache_share = true;
 
 	protected static $test_run_process_active = false;
 	protected $batch_mode = false;
@@ -81,6 +82,10 @@ class pts_test_run_manager
 	{
 		return $this->do_dynamic_run_count;
 	}
+	public function allow_test_cache_share()
+	{
+		return $this->allow_test_cache_share;
+	}
 	public function disable_dynamic_run_count()
 	{
 		$this->do_dynamic_run_count = false;
@@ -625,7 +630,7 @@ class pts_test_run_manager
 			return;
 		}
 
-		$active_result_buffer = pts_test_execution::run_test($this, $test_run_request);
+		pts_test_execution::run_test($this, $test_run_request);
 
 		if(pts_file_io::unlink(PTS_USER_PATH . 'halt-testing'))
 		{
@@ -662,7 +667,7 @@ class pts_test_run_manager
 				if(!empty($test_identifier))
 				{
 					$test_run_request->test_result_buffer = new pts_test_result_buffer();
-					$test_run_request->test_result_buffer->add_test_result($this->results_identifier, $test_run_request->active->get_result(), $active_result_buffer->get_values_as_string(), self::process_json_report_attributes($test_run_request), $test_run_request->active->get_min_result(), $test_run_request->active->get_max_result());
+					$test_run_request->test_result_buffer->add_test_result($this->results_identifier, $test_run_request->active->get_result(), $test_run_request->active->get_values_as_string(), self::process_json_report_attributes($test_run_request), $test_run_request->active->get_min_result(), $test_run_request->active->get_max_result());
 					$this->result_file->add_result($test_run_request);
 
 					if($test_run_request->secondary_linked_results != null && is_array($test_run_request->secondary_linked_results))
@@ -959,7 +964,18 @@ class pts_test_run_manager
 				}
 				else
 				{
-					pts_client::display_web_page(PTS_SAVE_RESULTS_PATH . $this->get_file_name() . '/index.html', null, true, false);
+					if((pts_client::read_env('DISPLAY') == false && pts_client::read_env('WAYLAND_DISPLAY') == false) && !defined('PHOROMATIC_PROCESS'))
+					{
+						$txt_results = pts_user_io::prompt_bool_input('Do you want to view the text results of the testing', true);
+						if($txt_results)
+						{
+							echo pts_result_file_output::result_file_to_text($this->result_file, pts_client::terminal_width());
+						}
+					}
+					else
+					{
+						pts_client::display_web_page(PTS_SAVE_RESULTS_PATH . $this->get_file_name() . '/index.html', null, true, false);
+					}
 				}
 			}
 
