@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009 - 2015, Phoronix Media
-	Copyright (C) 2009 - 2015, Michael Larabel
+	Copyright (C) 2009 - 2016, Phoronix Media
+	Copyright (C) 2009 - 2016, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -145,7 +145,7 @@ class cpu_usage extends phodevi_sensor
 		{
 			$stat = file_get_contents('/proc/stat');
 
-			if($this->cpu_to_monitor === "summary")
+			if($this->cpu_to_monitor === 'summary')
 			{
 				$start_line = 0;
 			}
