@@ -367,6 +367,12 @@ class pts_openbenchmarking
 		{
 			$repos[] = pts_openbenchmarking_client::user_name();
 		}
+		$on_system_indexes = glob(PTS_OPENBENCHMARKING_SCRATCH_PATH . '*.index');
+		foreach($on_system_indexes as $index)
+		{
+			$index = basename($index, '.index');
+			pts_arrays::unique_push($repos, $index);
+		}
 
 		return $repos;
 	}
