@@ -33,7 +33,7 @@ class pts_render
 		$graph->renderGraph();
 		return $graph->svg_dom->output($save_as);
 	}
-	public static function render_graph_inline_embed(&$object, &$result_file = null, $extra_attributes = null, $nested = true)
+	public static function render_graph_inline_embed(&$object, &$result_file = null, $extra_attributes = null, $nested = true, $output_format = 'SVG')
 	{
 		if($object instanceof pts_test_result)
 		{
@@ -54,7 +54,6 @@ class pts_render
 		}
 
 		$graph->renderGraph();
-		$output_format = 'SVG';
 		$graph = $graph->svg_dom->output(null, $output_format);
 
 		switch($output_format)
@@ -70,6 +69,8 @@ class pts_render
 					header('Content-Type: image/' . strtolower($output_format));
 				}
 				break;
+			case 'HTML':
+				break;
 			default:
 			case 'SVG':
 				if($nested)
@@ -155,8 +156,10 @@ class pts_render
 				$result_object->test_result_buffer->auto_shorten_buffer_identifiers($redundant_word_cache[$result_file->get_title()]);
 			}
 
+			$result_identifiers = $result_object->test_result_buffer->get_identifiers();
+
 			// COMPACT PROCESS
-			if(!isset($extra_attributes['compact_to_scalar']) && $result_object->test_profile->get_display_format() == 'LINE_GRAPH' && $result_file->get_system_count() > 7)
+			if(!isset($extra_attributes['compact_to_scalar']) && $result_object->test_profile->get_display_format() == 'LINE_GRAPH' && ($result_file->get_system_count() > 7 || $result_file->is_multi_way_comparison($result_identifiers, $extra_attributes)))
 			{
 				// If there's too many lines being plotted on line graph, likely to look messy, so convert to scalar automatically
 				$extra_attributes['compact_to_scalar'] = true;
@@ -164,8 +167,7 @@ class pts_render
 
 			// XXX: removed || $result_file->is_results_tracker() from below and should be added
 			// Removing the command fixes cases like: 1210053-BY-MYRESULTS43
-			$result_identifiers = $result_object->test_result_buffer->get_identifiers();
-			if($result_file->is_multi_way_comparison($result_identifiers, $extra_attributes) || isset($extra_attributes['compact_to_scalar']) || isset($extra_attributes['compact_scatter']))
+			if(isset($extra_attributes['compact_to_scalar']) || isset($extra_attributes['compact_scatter']) || $result_file->is_multi_way_comparison($result_identifiers, $extra_attributes))
 			{
 				if((isset($extra_attributes['compact_to_scalar']) || (false && $result_file->is_multi_way_comparison($result_identifiers, $extra_attributes))) && in_array($result_object->test_profile->get_display_format(), array('LINE_GRAPH', 'FILLED_LINE_GRAPH')))
 				{
@@ -327,6 +329,10 @@ class pts_render
 			if(isset($json['disk-scheduler']) && isset($json['disk-mount-options']))
 			{
 				$system_attributes['Disk'][$identifier] = $json['disk-scheduler'] . ' / ' . $json['disk-mount-options'];
+				if(isset($json['disk-details']) && !empty($json['disk-details']))
+				{
+					$system_attributes['Disk'][$identifier] .= ' / ' . $json['disk-details'];
+				}
 			}
 			if(isset($json['cpu-scaling-governor']))
 			{
