@@ -92,7 +92,11 @@ class pts_svg_dom_gd
 				'/usr/local/lib/X11/fonts/bitstream-vera/Vera.ttf',
 				'/usr/share/fonts/aajohan-comfortaa/Comfortaa-Regular.ttf',
 				'/Library/Fonts/Courier New.ttf',
-				'/Library/Fonts/Trebuchet MS.ttf'
+				'/Library/Fonts/Trebuchet MS.ttf',
+				'/usr/share/fonts/truetype/dejavu/DejaVuSans.ttf',
+				'/usr/share/fonts/truetype/ttf-bitstream-vera/Vera.ttf',
+				'/usr/share/fonts/truetype/freefont/FreeSans.ttf',
+				'/usr/share/fonts/truetype/liberation/LiberationSans-Regular.ttf',
 				);
 
 				foreach($possible_fonts as $font_file)
@@ -340,6 +344,9 @@ class pts_svg_dom_gd
 				}
 				imagecopyresampled($gd, $img, $a['x'], $a['y'], 0, 0, $a['width'], $a['height'], imagesx($img), imagesy($img));
 				break;
+			case 'path':
+				// TODO XXX
+				break;
 			default:
 				if(PTS_IS_CLIENT)
 				{
