@@ -41,6 +41,9 @@ class phoromatic_r_add_test_build_suite_details implements pts_webui_interface
 		$name = $test_profile->get_title();
 		$description = $test_profile->get_description();
 
+		$tid = 't_' . rand(1, 20000);
+		echo '<div id="' . $tid . '">';
+		echo '<p align="right"><a onclick="javascript:phoromatic_remove_from_suite_list(\'' . $tid  . '\');">Remove Test</a></p>';
 		echo '<h2>' . $name . ' [' . $test_profile->get_identifier() . '] </h2>';
 		echo '<p><em>' . $description . '</em></p>';
 		echo '<p>More information on this test can be found via <a target="_blank" href="http://openbenchmarking.org/test/' . $test_profile->get_identifier() . '">OpenBenchmarking.org</a>.</p>';
@@ -51,7 +54,6 @@ class phoromatic_r_add_test_build_suite_details implements pts_webui_interface
 		$test_prefix = "test_option_" . str_replace('.', '-', microtime(true)) . "_";
 		echo '<input type="hidden" name="test_prefix[]" value="' . $test_prefix . '" />';
 
-
 		if(count($test_options) == 0)
 		{
 			echo '<p><strong>No configurable user options for this test.</strong></p>';
@@ -72,13 +74,13 @@ class phoromatic_r_add_test_build_suite_details implements pts_webui_interface
 				else
 				{
 					echo '<input name="' . $test_prefix . $o->get_identifier() . '_selected" id="' . $test_prefix . $o->get_identifier() . '_selected" type="hidden" value="' . $o->get_name() . ': ' . $o->get_option_name(0) . '" />';
-					echo '<p><select name="' . $test_prefix . $o->get_identifier() . '" id="' . $test_prefix . $o->get_identifier() . '" onChange="phoromatic_test_select_update_selected_name(this);">';
+					echo '<p><select name="' . $test_prefix . $o->get_identifier() . '" id="' . $test_prefix . $o->get_identifier() . '" onChange="phoromatic_test_select_update_selected_name(this);" onload="phoromatic_test_select_update_selected_name(this);">';
 
 					$opts = array();
 					for($j = 0; $j < $option_count; $j++)
 					{
 						$v = $o->format_option_value_from_input($o->get_option_value($j));
-						echo '<option value="' . $v . '">' . $o->get_option_name($j) . '</option>';
+						echo '<option value="' . $v . '" ' . (isset($_GET['tpa']) && strpos($_GET['tpa'], $o->get_option_name($j)) !== false ? 'selected="selected"' : null) . '>' . $o->get_option_name($j) . '</option>';
 						$opts[] = $o->get_name() . ': ' . $o->get_option_name($j) . '::' . $v;
 					}
 					if($j > 1)
@@ -91,6 +93,7 @@ class phoromatic_r_add_test_build_suite_details implements pts_webui_interface
 			}
 		}
 		echo '<hr />';
+		echo '</div>';
 	}
 }
 
